==> ld64-97.17.tar.gz: ld64-97.17/unit-tests/test-cases/relocs-literals/test.c <==
/* -*- mode: C++; c-basic-offset: 4; tab-width: 4 -*- 
 *
 * Copyright (c) 2005 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */

const char*			foo = "foo";
const char* const	bar = "bar";

const char charArray1[] = "charArray1";
static const char charArray2[] = "charArray2";


const char* getString() { return "string"; }
const char* getString2() { return charArray2; }
const char* getString3() { return charArray1; }
const char* getString4() { return foo; }


float		f1 = 3.0;
double		d1 = 3.0;
long double ld1 = 3.0;



float getSingle() { return 1.0; }
double getDouble() { return 2.0; }
long double getLongDouble() { return 3.0; }


// rdar://problem/4732996
const char* stringFutz(int x) {
	return "hello" + 0x1000 + x;
}

const char*	usesAddend = "teststr" + 0x2000;

==> ld64-253.3.tar.gz: ld64-253.3/unit-tests/test-cases/relocs-literals/test.c <==
/* -*- mode: C++; c-basic-offset: 4; tab-width: 4 -*- 
 *
 * Copyright (c) 2005 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */

const char*			foo = "foo";
const char* const	bar = "bar";

const char charArray1[] = "charArray1";
static const char charArray2[] = "charArray2";


const char* getString() { return "string"; }
const char* getString2() { return charArray2; }
const char* getString3() { return charArray1; }
const char* getString4() { return foo; }


float		f1 = 3.0;
double		d1 = 3.0;
long double ld1 = 3.0;



float getSingle() { return 1.0; }
double getDouble() { return 2.0; }
long double getLongDouble() { return 3.0; }


// rdar://problem/4732996
const char* stringFutz(int x) {
	return &"hello"[0x1000 + x];
}

const char*	usesAddend = &"teststr"[0x2000];
